#! /bin/bash

# the driver files are copied to /tmp first, and we dynamically copy the
# relevant folders
logger "installing activdriver"
killall activmgr
killall activmonitor
killall activremote

# setup the necessary rights on the firmware update info directory
FWHISTORY="/var/Promethean/fwhistory"
groupadd activflash &> /dev/null
if [ ! -d "$FWHISTORY" ]; then
	mkdir -p $FWHISTORY &> /dev/null
	chgrp -R activflash $FWHISTORY &> /dev/null
	chmod g+w $FWHISTORY
fi

# first compile the kernel
cd /usr/src/promethean/kernel
echo "Installing kernel module. Output will be stored in /var/log/messages..."
DRIVER_INSTALLED=1
./b install 2>&1 | logger -s

if [ -f ".livecd" ]; then
	LIVECD_BUILD="1"
	echo -e "\\033[03;31mLive CD Build Detected.\\033[00m"
fi

if [ -z "$LIVECD_BUILD" ]; then

	if [ -f promethean.ko ]; then
		cp promethean.ko ..
	else
		DRIVER_INSTALLED=0
		tail /var/log/messages
		logger -s "Promethean: Error compiling new kernel module. You may need to install packages to compile kernel modules."
	fi

	# 2 - check if evdev is loaded
	if [ -e "/etc/modules" ]; then
		grep -i evdev /etc/modules >> /dev/null
		if [ $? -eq 0 ]; then
			echo "evdev already loaded"
		else
			echo "adding evdev to /etc/modules"
			echo -e "\nevdev\n" >> /etc/modules
			/sbin/modprobe evdev
		fi
	fi

	if [ $DRIVER_INSTALLED -eq 1 ]; then
		/sbin/depmod -a

		# modprobe promethean : the board may already be connected
		/sbin/modprobe promethean

		if [ $? -eq 0 ]; then
			echo Added Promethean module.
		else
			dmesg|tail
			echo Failed to modprobe Promethean kernel module.
			exit -4
		fi
	fi
fi # end livecd

# create a symbolic link /dev/input/activdevices, to be used by xorg driver
if [ ! -e "/dev/input/activdevices" ]; then
	mkfifo /dev/input/activdevices
fi

if [ ! -e "/tmp/activboard" ]; then
	mkdir /tmp/activboard
	chmod 777 /tmp/activboard
fi	

# append the xorg.conf if not already in

echo -e "\\033[03;31mPlease restart X before using the board."
echo -e "This can be done by logging out (safe method) or pressing CTRL-ALT-BACKSPACE (unsafe).\\033[00m"

# install the activdevices service

# /etc/init.d (debian-based, fc, etc...)
if [ -d "/etc/init.d" ]; then
        cp /tmp/promethean/driver/activdevices /etc/init.d
        chmod +x /etc/init.d/activdevices

		CHKCONFIG=`whereis -b chkconfig|cut -d: -f 2|awk '{print $1}'`
        if [ "$CHKCONFIG" != "" ]; then
                $CHKCONFIG --add activdevices > /dev/null
        else
		if [ -x '/sbin/insserv' ]; then
			/sbin/insserv activdevices
		else
			UPDATERCD=`whereis -b update-rc.d|cut -d: -f 2|awk '{print $1}'`
			if [ "$UPDATERCD" != "" ]; then
			        $UPDATERCD activdevices start 05 2 3 4 5 . stop 05 0 1 6 . > /dev/null
			fi
		fi

		
	fi
elif [ -d "/etc/rc5.d" ]; then
		# old style, copy straight into rc<n>.d
		if [ -d /etc/rc5.d ]; then
        	cp /tmp/promethean/driver/activdevices /etc/rc5.d
        	chmod +x /etc/rc5.d/activdevices
        fi

		if [ -d /etc/rc3.d ]; then
        	cp /tmp/promethean/driver/activdevices /etc/rc3.d
        	chmod +x /etc/rc3.d/activdevices
        fi
fi



if [ -z "$LIVECD_BUILD" ]; then
	TEXT="You must logout once the installation is complete in order to use your Promethean devices."

	# tell people what to do...
	echo "-$DISPLAY-"
	if [ -n "$DISPLAY" -a -n "$TEXT" ]; then
			if [ -x "`which zenity`" ]; then
				zenity --info --title "Promethean Activdriver" --text "$TEXT" &
				disown zenity
			elif [ -x "`which Xdialog`" ]; then
				XDialog --title "Promethean Activdriver" --infobox "$TEXT" 480x140 0 &
				disown XDialog
			else
				echo "$TEXT"|wall
			fi

	fi
fi

exit 0
